@@ -34,8 +34,8 @@ try:
 except ImportError:
     import json
 
-from oslo.utils import encodeutils
-from oslo.utils import importutils
+from oslo_utils import encodeutils
+from oslo_utils import importutils
 import requests
 
 from tuskarclient.openstack.common._i18n import _
